==> geeklog-1.7.1-jp-extended-1.0.zip: geeklog-1.7.1-jp-extended-1.0/plugins/calendar/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the Estonian language file for the Geeklog Calendar plugin
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
# Copyright (C) 2005 Trinity Bays
# trinity93@gmail.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

# index.php
$LANG_CAL_1 = array(
    1 => 'Sndmuste kalender',
    2 => 'Kahjuks pole htegi sndmust, mida nidata.',
    3 => 'Millal',
    4 => 'Kus',
    5 => 'Kirjeldus',
    6 => 'Lisa sndmus',
    7 => 'Tuleviku sndmused',
    8 => 'Lisades selle sndmuse oma kalendrisse saad kiire levaate just sind huvitavatest sndmustest, kui klpsad "Kasutaja funktsioonid" valikute hulgas "Minu kalender".',
    9 => 'Lisa minu kalendrisse',
    10 => 'Eemalda minu kalendrist',
    11 => "Sndmuse lisamine {$_USER['username']} kalendrisse",
    12 => 'Sndmus',
    13 => 'Algab',
    14 => 'Lpeb',
    15 => 'Tagasi kalendrisse',
    16 => 'Kalender',
    17 => 'Alguspev',
    18 => 'Lpupev',
    19 => 'Sisestused kalendrisse',
    20 => 'Tiitel',
    21 => 'Algusaeg',
    22 => 'URL',
    23 => 'Sinu sndmused',
    24 => 'Sndmused',
    25 => 'Pole tulevasi sndmusi',
    26 => 'Lisa sndmus',
    27 => "Lisades {$_CONF['site_name']} lehele sndmuse, paigutub see peakalendrisse, kust kasutajad saavad soovi korral lisada selle oma enda isiklikku kalendrisse. Lehe kalender <b>ei ole </b> meldud teie isiklike sndmuste, nagu snnipevade vi thtpevade jaoks.<br" . XHTML . "><br" . XHTML . ">Prast sndmuse lisamist saadetakse see meie administraatoritele. Administraatorite poolt kinnitatud sndmus ilmub peakalendrisse.",
    28 => 'Tiitel',
    29 => 'Lpuaeg',
    30 => 'Algusaeg',
    31 => 'Kogu peva sndmus',
    32 => 'Aadressrida 1',
    33 => 'Aadressrida 2',
    34 => 'Linn',
    35 => 'Piirkond',
    36 => 'postiindeks',
    37 => 'Sndmuse tp',
    38 => 'Toimeta sndmuste tpe',
    39 => 'Asukoht',
    40 => 'Lisa sndmus - ',
    41 => 'Peakalender',
    42 => 'Isiklik kalender',
    43 => 'Link',
    44 => 'HTML sildid pole lubatud',
    45 => 'Sisesta',
    46 => 'Sndmused lehel',
    47 => 'Top 10 sndmust',
    48 => 'klikke',
    49 => 'Nib, et saidil pole htegi sndmust vi mitte keegi pole neil klpsanud.',
    50 => 'Sndmused',
    51 => 'Kustuta'
);

$_LANG_CAL_SEARCH = array(
    'results' => 'Kalendri tulemused',
    'title' => 'Tiitel',
    'date_time' => 'Pev ja kellaaeg',
    'location' => 'Asukoht',
    'description' => 'Kirjeldus'
);

###############################################################################
# calendar.php ($LANG30)

$LANG_CAL_2 = array(
    8 => 'Lisa sndmus',
    9 => '%s sndmus',
    10 => 'Sndmused, kasutaja',
    11 => 'Peakalender',
    12 => 'Minu kalender',
    25 => 'tagasi ',
    26 => 'Kogu pev',
    27 => 'Ndal',
    28 => 'Isiklik kalender, kasutaja',
    29 => 'Avalik kalender',
    30 => 'kustuta sndmus',
    31 => 'Lisa',
    32 => 'Sndmus',
    33 => 'Kuupev',
    34 => 'Aeg',
    35 => 'Kiirlisamine',
    36 => 'Sisesta',
    37 => 'Isiklik kalender ei ole sellel lehel kahjuks aktiveeritud.',
    38 => 'Isiklik sndmuste toimetaja',
    39 => 'Pev',
    40 => 'Ndal',
    41 => 'Kuu',
    42 => 'Lisa peasndmus',
    43 => 'Sisestatud sndmused'
);

###############################################################################
# admin/plugins/calendar/index.php, formerly admin/event.php ($LANG22)

$LANG_CAL_ADMIN = array(
    1 => 'Sndmuste toimetaja',
    2 => 'Viga',
    3 => 'Sndmuse tiitel',
    4 => 'Sndmuse URL',
    5 => 'Sndmuse algusaeg',
    6 => 'Sndmuse lpuaeg',
    7 => 'Sndmuse asukoht',
    8 => 'Sndmuse kirjeldus',
    9 => '(koos http://)',
    10 => 'Sa pead mrama sndmuse aja ja kellaaja, tiitli ja kirjelduse',
    11 => 'Sndmuste haldaja',
    12 => 'Sndmuse toimetamiseks vi kustutamiseks klpsa allpool selle tiitlil.  Uue sndmuse loomiseks klpsa Tee uus lal. Klpsa [C] olemasolevast sndmusest koopia tegemiseks.',
    13 => 'Sndmuse tiitel',
    14 => 'Alguspev',
    15 => 'lpupev',
    16 => '',
    17 => "Sa proovisid ligi pseda sndmusele, millele sul pole igust ligi pseda. See katse on logitud. Palun <a href=\"{$_CONF['site_admin_url']}/plugins/calendar/\">mine tagasi sndmuste haldamise lehele</a>.",
    18 => '',
    19 => '',
    20 => 'salvesta',
    21 => 'thista',
    22 => 'kustuta',
    23 => 'Sobimatu algusaeg.',
    24 => 'Sobimatu lpuaeg.',
    25 => 'Lpuaeg on enne algusaega.',
    26 => 'Kustuta vanad kanded',
    27 => 'Need on sndmused, mis on vanemad kui ',
    28 => ' kuud. Nende kustutamiseks klpsa lehe allosas oleval prgikasti nupul vi vali teine ajavahemik:<br' . XHTML . '> Leia sndmused, mis on vanemad kui ',
    29 => ' kuud.',
    30 => 'Vrskenda loetelu',
    31 => 'Oled sa kindel, et soovid kustutada kik valitud kasutajad?',
    32 => 'Nita kiki',
    33 => 'Kustutamiseks pole valitud htegi sndmust',
    34 => 'Sndmuse ID',
    35 => 'ei kustutatud ',
    36 => 'Edukalt kustutatud'
);

$LANG_CAL_MESSAGE = array(
    'save' => 'Sinu sndmus on edukalt salvestatud.',
    'delete' => 'Sndmus on edukalt kustutatud.',
    'private' => 'Sndmus on sinu kalendrisse salvestatud.',
    'login' => 'Ei saa enne sinu sisselogimist sinu isiklikku kalendrit avada',
    'removed' => 'Sndmus on sinu isiklikust kalendrist kustutatud.',
    'noprivate' => 'Kahjuks pole sellel lehel isiklikud kalendrid kasutuses.',
    'unauth' => 'Sul pole ligipsu sndmuste haldamise lehele. Pane thele, et kik sellised lubamatud katsed logitakse'
);

$PLG_calendar_MESSAGE4 = "Tname sind {$_CONF['site_name']} lehele sndmuse sisestamise eest.  See saadeti meie meeskonnale kinnitamiseks. Prast kinnitamist on see sndmus nha <a href=\"{$_CONF['site_url']}/calendar/\">kalendri</a> osas.";
$PLG_calendar_MESSAGE17 = 'Sndmus on edukalt salvestatud.';
$PLG_calendar_MESSAGE18 = 'Sinu sndmus on edukalt kustutatud.';
$PLG_calendar_MESSAGE24 = 'Sndmus on sinu kalendrisse salvestatud.';
$PLG_calendar_MESSAGE26 = 'Sndmus on edukalt kustutatud.';

// Messages for the plugin upgrade
$PLG_calendar_MESSAGE3001 = 'Plugina uuendamine pole toetatud.';
$PLG_calendar_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['calendar'] = array(
    'label' => 'Kalender',
    'title' => 'Kalendrihaldur'
);

$LANG_confignames['calendar'] = array(
    'calendarloginrequired' => 'Kalender vajab sisselogimist?',
    'hidecalendarmenu' => 'Peida kalendri menpunkt?',
    'personalcalendars' => 'Luba isiklikud kalendrid?',
    'eventsubmission' => 'Luba sisestustepuhver?',
    'showupcomingevents' => 'Nita tulevasi sndmusi?',
    'upcomingeventsrange' => 'Tulevaste sndmuste ajavahemik',
    'event_types' => 'Sndmuste tbid',
    'hour_mode' => 'Tunnireiim',
    'notification' => 'Teavituskiri?',
    'delete_event' => 'Kustuta sndmused, omanikuks?',
    'aftersave' => 'Prast sndmuste salvestamist',
    'default_permissions' => 'Sndmuste vaikimisi igused'
);

$LANG_configsubgroups['calendar'] = array(
    'sg_main' => 'Peahlestused'
);

$LANG_fs['calendar'] = array(
    'fs_main' => 'Kalendri ldised hlestused',
    'fs_permissions' => 'Vaikimisi igused'
);

// Note: entries 0, 1, 6, 9, 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['calendar'] = array(
    0 => array('Jah' => 1, 'Ei' => 0),
    1 => array('Jah' => true, 'Ei' => false),
    6 => array('12' => 12, '24' => 24),
    9 => array('Suuna sndmuste juurde' => 'item', 'Nita administreerimisloetelu' => 'list', 'Nita kalendrit' => 'plugin', 'Nita avalehte' => 'home', 'Nita admini lehte' => 'admin'),
    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3)
);

?>

==> geeklog-2.0.0-jp-extended-1.0.zip: geeklog-2.0.0-jp-extended-1.0/plugins/calendar/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the Estonian language file for the Geeklog Calendar plugin
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
# Copyright (C) 2005 Trinity Bays
# trinity93@gmail.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

# index.php
$LANG_CAL_1 = array(
    1 => 'Sndmuste kalender',
    2 => 'Kahjuks pole htegi sndmust, mida nidata.',
    3 => 'Millal',
    4 => 'Kus',
    5 => 'Kirjeldus',
    6 => 'Lisa sndmus',
    7 => 'Tuleviku sndmused',
    8 => 'Lisades selle sndmuse oma kalendrisse saad kiire levaate just sind huvitavatest sndmustest, kui klpsad "Kasutaja funktsioonid" valikute hulgas "Minu kalender".',
    9 => 'Lisa minu kalendrisse',
    10 => 'Eemalda minu kalendrist',
    11 => "Sndmuse lisamine {$_USER['username']} kalendrisse",
    12 => 'Sndmus',
    13 => 'Algab',
    14 => 'Lpeb',
    15 => 'Tagasi kalendrisse',
    16 => 'Kalender',
    17 => 'Alguspev',
    18 => 'Lpupev',
    19 => 'Sisestused kalendrisse',
    20 => 'Tiitel',
    21 => 'Algusaeg',
    22 => 'URL',
    23 => 'Sinu sndmused',
    24 => 'Sndmused',
    25 => 'Pole tulevasi sndmusi',
    26 => 'Lisa sndmus',
    27 => "Lisades {$_CONF['site_name']} lehele sndmuse, paigutub see peakalendrisse, kust kasutajad saavad soovi korral lisada selle oma enda isiklikku kalendrisse. Lehe kalender <b>ei ole </b> meldud teie isiklike sndmuste, nagu snnipevade vi thtpevade jaoks.<br" . XHTML . "><br" . XHTML . ">Prast sndmuse lisamist saadetakse see meie administraatoritele. Administraatorite poolt kinnitatud sndmus ilmub peakalendrisse.",
    28 => 'Tiitel',
    29 => 'Lpuaeg',
    30 => 'Algusaeg',
    31 => 'Kogu peva sndmus',
    32 => 'Aadressrida 1',
    33 => 'Aadressrida 2',
    34 => 'Linn',
    35 => 'Piirkond',
    36 => 'postiindeks',
    37 => 'Sndmuse tp',
    38 => 'Toimeta sndmuste tpe',
    39 => 'Asukoht',
    40 => 'Lisa sndmus - ',
    41 => 'Peakalender',
    42 => 'Isiklik kalender',
    43 => 'Link',
    44 => 'HTML sildid pole lubatud',
    45 => 'Sisesta',
    46 => 'Sndmused lehel',
    47 => 'Top 10 sndmust',
    48 => 'klikke',
    49 => 'Nib, et saidil pole htegi sndmust vi mitte keegi pole neil klpsanud.',
    50 => 'Sndmused',
    51 => 'Kustuta',
    'autotag_desc_event' => '[event: id alternate title] - Displays a link to an Event Link from the Calendar using the Event Title as the title. An alternate title may be specified but is not required.'
);

$_LANG_CAL_SEARCH = array(
    'results' => 'Kalendri tulemused',
    'title' => 'Tiitel',
    'date_time' => 'Pev ja kellaaeg',
    'location' => 'Asukoht',
    'description' => 'Kirjeldus'
);

###############################################################################
# calendar.php ($LANG30)

$LANG_CAL_2 = array(
    8 => 'Lisa sndmus',
    9 => '%s sndmus',
    10 => 'Sndmused, kasutaja',
    11 => 'Peakalender',
    12 => 'Minu kalender',
    25 => 'tagasi ',
    26 => 'Kogu pev',
    27 => 'Ndal',
    28 => 'Isiklik kalender, kasutaja',
    29 => 'Avalik kalender',
    30 => 'kustuta sndmus',
    31 => 'Lisa',
    32 => 'Sndmus',
    33 => 'Kuupev',
    34 => 'Aeg',
    35 => 'Kiirlisamine',
    36 => 'Sisesta',
    37 => 'Isiklik kalender ei ole sellel lehel kahjuks aktiveeritud.',
    38 => 'Isiklik sndmuste toimetaja',
    39 => 'Pev',
    40 => 'Ndal',
    41 => 'Kuu',
    42 => 'Lisa peasndmus',
    43 => 'Sisestatud sndmused'
);

###############################################################################
# admin/plugins/calendar/index.php, formerly admin/event.php ($LANG22)

$LANG_CAL_ADMIN = array(
    1 => 'Sndmuste toimetaja',
    2 => 'Viga',
    3 => 'Sndmuse tiitel',
    4 => 'Sndmuse URL',
    5 => 'Sndmuse algusaeg',
    6 => 'Sndmuse lpuaeg',
    7 => 'Sndmuse asukoht',
    8 => 'Sndmuse kirjeldus',
    9 => '(koos http://)',
    10 => 'Sa pead mrama sndmuse aja ja kellaaja, tiitli ja kirjelduse',
    11 => 'Sndmuste haldaja',
    12 => 'Sndmuse toimetamiseks vi kustutamiseks klpsa allpool selle tiitlil.  Uue sndmuse loomiseks klpsa Tee uus lal. Klpsa [C] olemasolevast sndmusest koopia tegemiseks.',
    13 => 'Sndmuse tiitel',
    14 => 'Alguspev',
    15 => 'lpupev',
    16 => '',
    17 => "Sa proovisid ligi pseda sndmusele, millele sul pole igust ligi pseda. See katse on logitud. Palun <a href=\"{$_CONF['site_admin_url']}/plugins/calendar/\">mine tagasi sndmuste haldamise lehele</a>.",
    18 => '',
    19 => '',
    20 => 'salvesta',
    21 => 'thista',
    22 => 'kustuta',
    23 => 'Sobimatu algusaeg.',
    24 => 'Sobimatu lpuaeg.',
    25 => 'Lpuaeg on enne algusaega.',
    26 => 'Kustuta vanad kanded',
    27 => 'Need on sndmused, mis on vanemad kui ',
    28 => ' kuud. Nende kustutamiseks klpsa lehe allosas oleval prgikasti nupul vi vali teine ajavahemik:<br' . XHTML . '> Leia sndmused, mis on vanemad kui ',
    29 => ' kuud.',
    30 => 'Vrskenda loetelu',
    31 => 'Oled sa kindel, et soovid kustutada kik valitud kasutajad?',
    32 => 'Nita kiki',
    33 => 'Kustutamiseks pole valitud htegi sndmust',
    34 => 'Sndmuse ID',
    35 => 'ei kustutatud ',
    36 => 'Edukalt kustutatud'
);

$LANG_CAL_MESSAGE = array(
    'save' => 'Sinu sndmus on edukalt salvestatud.',
    'delete' => 'Sndmus on edukalt kustutatud.',
    'private' => 'Sndmus on sinu kalendrisse salvestatud.',
    'login' => 'Ei saa enne sinu sisselogimist sinu isiklikku kalendrit avada',
    'removed' => 'Sndmus on sinu isiklikust kalendrist kustutatud.',
    'noprivate' => 'Kahjuks pole sellel lehel isiklikud kalendrid kasutuses.',
    'unauth' => 'Sul pole ligipsu sndmuste haldamise lehele. Pane thele, et kik sellised lubamatud katsed logitakse'
);

$PLG_calendar_MESSAGE4 = "Tname sind {$_CONF['site_name']} lehele sndmuse sisestamise eest.  See saadeti meie meeskonnale kinnitamiseks. Prast kinnitamist on see sndmus nha <a href=\"{$_CONF['site_url']}/calendar/\">kalendri</a> osas.";
$PLG_calendar_MESSAGE17 = 'Sndmus on edukalt salvestatud.';
$PLG_calendar_MESSAGE18 = 'Sinu sndmus on edukalt kustutatud.';
$PLG_calendar_MESSAGE24 = 'Sndmus on sinu kalendrisse salvestatud.';
$PLG_calendar_MESSAGE26 = 'Sndmus on edukalt kustutatud.';

// Messages for the plugin upgrade
$PLG_calendar_MESSAGE3001 = 'Plugina uuendamine pole toetatud.';
$PLG_calendar_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['calendar'] = array(
    'label' => 'Kalender',
    'title' => 'Kalendrihaldur'
);

$LANG_confignames['calendar'] = array(
    'calendarloginrequired' => 'Kalender vajab sisselogimist?',
    'hidecalendarmenu' => 'Peida kalendri menpunkt?',
    'personalcalendars' => 'Luba isiklikud kalendrid?',
    'eventsubmission' => 'Luba sisestustepuhver?',
    'showupcomingevents' => 'Nita tulevasi sndmusi?',
    'upcomingeventsrange' => 'Tulevaste sndmuste ajavahemik',
    'event_types' => 'Sndmuste tbid',
    'hour_mode' => 'Tunnireiim',
    'notification' => 'Teavituskiri?',
    'delete_event' => 'Kustuta sndmused, omanikuks?',
    'aftersave' => 'Prast sndmuste salvestamist',
    'default_permissions' => 'Sndmuste vaikimisi igused',
    'autotag_permissions_event' => '[event: ] Permissions',
    'block_enable' => 'Enabled',
    'block_isleft' => 'Display Block on Left',
    'block_order' => 'Block Order',
    'block_topic_option' => 'Topic Options',
    'block_topic' => 'Topic',
    'block_group_id' => 'Group',
    'block_permissions' => 'Permissions'
);

$LANG_configsubgroups['calendar'] = array(
    'sg_main' => 'Peahlestused'
);

$LANG_tab['calendar'] = array(
    'tab_main' => 'General Calendar Settings',
    'tab_permissions' => 'Default Permissions',
    'tab_autotag_permissions' => 'Autotag Usage Permissions',
    'tab_events_block' => 'Events Block'
);

$LANG_fs['calendar'] = array(
    'fs_main' => 'Kalendri ldised hlestused',
    'fs_permissions' => 'Vaikimisi igused',
    'fs_autotag_permissions' => 'Autotag Usage Permissions',
    'fs_block_settings' => 'Block Settings',
    'fs_block_permissions' => 'Block Permissions'
);

// Note: entries 0, 1, 6, 9, 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['calendar'] = array(
    0 => array('Jah' => 1, 'Ei' => 0),
    1 => array('Jah' => true, 'Ei' => false),
    6 => array('12' => 12, '24' => 24),
    9 => array('Suuna sndmuste juurde' => 'item', 'Nita administreerimisloetelu' => 'list', 'Nita kalendrit' => 'plugin', 'Nita avalehte' => 'home', 'Nita admini lehte' => 'admin'),
    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3),
    13 => array('No access' => 0, 'Use' => 2),
    14 => array('No access' => 0, 'Read-Only' => 2),
    15 => array('All' => 'TOPIC_ALL_OPTION', 'Homepage Only' => 'TOPIC_HOMEONLY_OPTION', 'Select Topics' => 'TOPIC_SELECTED_OPTION')
);

?>
